==> bce-java-sdk-0.10.75-sources.jar: com/baidubce/services/bcc/model/instance/StopInstanceRequest.java <==
/*
 * Copyright (c) 2014 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bcc.model.instance;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import com.fasterxml.jackson.annotation.JsonIgnore;

/**
 * The request for stopping the instance.
 */
public class StopInstanceRequest extends AbstractBceRequest {

    /**
     * The id of instance.
     */
    @JsonIgnore
    private String instanceId;

    /**
     * The option param to stop the instance forcibly, default value is false.
     * If <code>true</code>, it will stop the instance just like power off immediately
     * and it may result int losing important data which have not written to disk.
     */
    private boolean forceStop = false;

    public String getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(String instanceId) {
        this.instanceId = instanceId;
    }

    /**
     * Configure instanceId for the request.
     *
     * @param instanceId The id of the instance.
     * @return StopInstanceRequest with instanceId.
     */
    public StopInstanceRequest withInstanceId(String instanceId) {
        this.instanceId = instanceId;
        return this;
    }


    public boolean isForceStop() {
        return forceStop;
    }

    public void setForceStop(boolean forceStop) {
        this.forceStop = forceStop;
    }

    /**
     * Configure forceStop for the request.
     *
     * @param forceStop The option param to stop the instance forcibly, default value is false.
     *                  If <code>true</code>, it will stop the instance just like power off immediately
     *                  and it may result int losing important data which have not written to disk.
     * @return StopInstanceRequest with forceStop.
     */
    public StopInstanceRequest withForceStop(boolean forceStop) {
        this.forceStop = forceStop;
        return this;
    }

    /**
     * Configure request credential for the request.
     *
     * @param credentials a valid instance of BceCredentials.
     * @return StopInstanceRequest with credentials.
     */
    @Override
    public StopInstanceRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }
}

==> bce-java-sdk-0.10.181-sources.jar: com/baidubce/services/bcc/model/instance/StopInstanceRequest.java <==
/*
 * Copyright (c) 2014-2020 Baidu.com, Inc. All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.bcc.model.instance;

import com.baidubce.auth.BceCredentials;
import com.baidubce.model.AbstractBceRequest;
import com.fasterxml.jackson.annotation.JsonIgnore;

/**
 * The request for stopping the instance.
 */
public class StopInstanceRequest extends AbstractBceRequest {

    /**
     * The id of instance.
     */
    @JsonIgnore
    private String instanceId;

    /**
     * The option param to stop the instance forcibly, default value is false.
     * If <code>true</code>, it will stop the instance just like power off immediately
     * and it may result int losing important data which have not written to disk.
     */
    private boolean forceStop = false;

    /**
     * The option param to indicate that whether the instance can be stopped with no charge or not,
     * default value is false. If <code>true</>, it means the instance can be stopped with no charge.
     */
    private boolean stopWithNoCharge;

    public String getInstanceId() {
        return instanceId;
    }

    public void setInstanceId(String instanceId) {
        this.instanceId = instanceId;
    }

    /**
     * Configure instanceId for the request.
     *
     * @param instanceId The id of the instance.
     * @return StopInstanceRequest with instanceId.
     */
    public StopInstanceRequest withInstanceId(String instanceId) {
        this.instanceId = instanceId;
        return this;
    }


    public boolean isForceStop() {
        return forceStop;
    }

    public void setForceStop(boolean forceStop) {
        this.forceStop = forceStop;
    }

    /**
     * Configure forceStop for the request.
     *
     * @param forceStop The option param to stop the instance forcibly, default value is false.
     *                  If <code>true</code>, it will stop the instance just like power off immediately
     *                  and it may result int losing important data which have not written to disk.
     * @return StopInstanceRequest with forceStop.
     */
    public StopInstanceRequest withForceStop(boolean forceStop) {
        this.forceStop = forceStop;
        return this;
    }

    public boolean isStopWithNoCharge() {
        return stopWithNoCharge;
    }

    public void setStopWithNoCharge(boolean stopWithNoCharge) {
        this.stopWithNoCharge = stopWithNoCharge;
    }

    /**
     * Configure stopWithNoCharge for the request.
     * @param stopWithNoCharge The option param to indicate that whether the instance can be stopped
     *                         with no charge or not, default value is false. If <code>true</>,
     *                         it means the instance can be stopped with no charge.
     * @return StopInstanceRequest with stopWithNoCharge.
     */
    public StopInstanceRequest withStopWithNoCharge(boolean stopWithNoCharge) {
        this.stopWithNoCharge = stopWithNoCharge;
        return this;
    }

    /**
     * Configure request credential for the request.
     *
     * @param credentials a valid instance of BceCredentials.
     * @return StopInstanceRequest with credentials.
     */
    @Override
    public StopInstanceRequest withRequestCredentials(BceCredentials credentials) {
        this.setRequestCredentials(credentials);
        return this;
    }
}
